@@ -1,9 +1,10 @@
 # encoding: ascii-8bit
+# frozen_string_literal: true
 
 require 'snmp/pdu'
 require 'minitest/autorun'
 
-class TestProtocol < MiniTest::Unit::TestCase
+class TestProtocol < Minitest::Test
 
   include SNMP
 
@@ -94,9 +95,9 @@ class TestProtocol < MiniTest::Unit::TestCase
   end
 
   def test_get_bulk_create
-    request = SNMP::GetBulkRequest.new(1234, VarBindList.new("1.3.6.2"), 0, 10)
+    request = SNMP::GetBulkRequest.new(1234, VarBindList.new("1.3.6.2"), 20, 10)
     assert_equal(1234, request.request_id)
-    assert_equal(0, request.non_repeaters)
+    assert_equal(20, request.non_repeaters)
     assert_equal(10, request.max_repetitions)
     assert_equal(1, request.varbind_list.length)
     assert_equal("1.3.6.2", request.varbind_list.first.name.to_s)
@@ -117,7 +118,12 @@ class TestProtocol < MiniTest::Unit::TestCase
     request.error_status = 2
     assert_equal(:noSuchName, request.error_status)
 
-    assert_raises(InvalidErrorStatus) {request.error_status = 42}
+    request.error_status = 42
+    assert_equal(42, request.error_status)
+
+    assert_raises(InvalidErrorStatus) {request.error_status = "myErrorString"}
+    
+    assert_raises(InvalidErrorStatus) {request.error_status = :myErrorSymbol}
   end
 
   def test_snmpv2_trap
@@ -184,4 +190,12 @@ class TestProtocol < MiniTest::Unit::TestCase
     assert_equal(0, pdu.varbind_list.length)
   end
 
+  def test_response_pdu_unknown_error
+    pdu = Response.new(2147483647, VarBindList.new, 6883501, 0)
+    assert_equal("\xA2\x10\x02\x04\x7F\xFF\xFF\xFF\x02\x03\x69\x08\xAD\x02\x01\x00\x30\x00", pdu.encode)
+
+    encoded = Message.new(:SNMPv2c, "public", pdu).encode
+    pdu = Message.decode(encoded).pdu
+    assert_equal(6883501, pdu.error_status)
+  end
 end
